@@ -27,6 +27,7 @@ use Doctrine\ORM\OptimisticLockException;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\Utility\HierarchyDiscriminatorResolver;
 use Doctrine\ORM\Utility\PersisterHelper;
+use function trim;
 
 /**
  * The SqlWalker is a TreeWalker that walks over a DQL AST and constructs
@@ -141,6 +142,8 @@ class SqlWalker implements TreeWalker
      * Map of all components/classes that appear in the DQL query.
      *
      * @var array
+     *
+     * @psalm-var array<string, array{metadata: ClassMetadata}>
      */
     private $queryComponents;
 
@@ -198,7 +201,7 @@ class SqlWalker implements TreeWalker
     /**
      * Gets the Query instance used by the walker.
      *
-     * @return Query.
+     * @return Query
      */
     public function getQuery()
     {
@@ -231,6 +234,8 @@ class SqlWalker implements TreeWalker
      * @param string $dqlAlias The DQL alias.
      *
      * @return array
+     *
+     * @psalm-return array{metadata: ClassMetadata}
      */
     public function getQueryComponent($dqlAlias)
     {
@@ -1521,7 +1526,7 @@ class SqlWalker implements TreeWalker
     /**
      * @param \Doctrine\ORM\Query\AST\ParenthesisExpression $parenthesisExpression
      *
-     * @return string.
+     * @return string
      */
     public function walkParenthesisExpression(AST\ParenthesisExpression $parenthesisExpression)
     {
@@ -1553,12 +1558,20 @@ class SqlWalker implements TreeWalker
                     break;
 
                 case ($e instanceof AST\PathExpression):
-                    $dqlAlias  = $e->identificationVariable;
-                    $qComp     = $this->queryComponents[$dqlAlias];
-                    $class     = $qComp['metadata'];
-                    $fieldType = $class->fieldMappings[$e->field]['type'];
+                    $dqlAlias     = $e->identificationVariable;
+                    $qComp        = $this->queryComponents[$dqlAlias];
+                    $class        = $qComp['metadata'];
+                    $fieldType    = $class->fieldMappings[$e->field]['type'];
+                    $fieldName    = $e->field;
+                    $fieldMapping = $class->fieldMappings[$fieldName];
+                    $col          = trim($e->dispatch($this));
 
-                    $sqlSelectExpressions[] = trim($e->dispatch($this)) . ' AS ' . $columnAlias;
+                    if (isset($fieldMapping['requireSQLConversion'])) {
+                        $type = Type::getType($fieldType);
+                        $col  = $type->convertToPHPValueSQL($col, $this->platform);
+                    }
+
+                    $sqlSelectExpressions[] = $col . ' AS ' . $columnAlias;
                     break;
 
                 case ($e instanceof AST\Literal):
