@@ -149,7 +149,7 @@ class EntityGenerator
     /**
      * Whether or not to make generated embeddables immutable.
      *
-     * @var boolean.
+     * @var bool
      */
     protected $embeddablesImmutable = false;
 
@@ -342,9 +342,7 @@ public function __construct(<params>)
     {
         @trigger_error(self::class . ' is deprecated and will be removed in Doctrine ORM 3.0', E_USER_DEPRECATED);
 
-        if (version_compare(\Doctrine\Common\Version::VERSION, '2.2.0-DEV', '>=')) {
-            $this->annotationsPrefix = 'ORM\\';
-        }
+        $this->annotationsPrefix = 'ORM\\';
     }
 
     /**
@@ -1166,7 +1164,7 @@ public function __construct(<params>)
         $inheritanceClassMap = [];
 
         foreach ($metadata->discriminatorMap as $type => $class) {
-            $inheritanceClassMap[] .= '"' . $type . '" = "' . $class . '"';
+            $inheritanceClassMap[] = '"' . $type . '" = "' . $class . '"';
         }
 
         return '@' . $this->annotationsPrefix . 'DiscriminatorMap({' . implode(', ', $inheritanceClassMap) . '})';
@@ -1468,7 +1466,7 @@ public function __construct(<params>)
         }
 
         if (isset($joinColumn['unique']) && $joinColumn['unique']) {
-            $joinColumnAnnot[] = 'unique=' . ($joinColumn['unique'] ? 'true' : 'false');
+            $joinColumnAnnot[] = 'unique=true';
         }
 
         if (isset($joinColumn['nullable'])) {
@@ -1560,7 +1558,7 @@ public function __construct(<params>)
             }
 
             if (isset($associationMapping['orphanRemoval']) && $associationMapping['orphanRemoval']) {
-                $typeOptions[] = 'orphanRemoval=' . ($associationMapping['orphanRemoval'] ? 'true' : 'false');
+                $typeOptions[] = 'orphanRemoval=true';
             }
 
             if (isset($associationMapping['fetch']) && $associationMapping['fetch'] !== ClassMetadataInfo::FETCH_LAZY) {
